@@ -53,29 +53,52 @@ perform.knn = function(training.set, test.set,
   #knn.cv(training.set[,-1],classes,k=k.value,prob=T)
   # get final results
   classification.results = as.character(classification.results)
+  
   # let's see who gets linked to whom: adding names to the results
   names(classification.results) = rownames(test.set)
 
 
+  
     # preparing a confusion table
     predicted_classes = classification.results
     expected_classes = classes.test.set
 
-    classes_all = sort(unique(as.character(c(expected_classes, predicted_classes))))
+    classes_all = sort(unique(as.character(c(expected_classes, classes.training.set))))
     predicted = factor(as.character(predicted_classes), levels = classes_all)
     expected  = factor(as.character(expected_classes), levels = classes_all)
     confusion_matrix = table(expected, predicted)
 
-# getting rid of the classes not represented in the training set (e.g. anonymous samples)
-#confusion_matrix = confusion_matrix[,rownames(confusion_matrix)]
+
+    # shorten the names of the variables
+    y = classification.results
+    # predicted = predicted_classes
+    # expected = expected_classes
+    # misclassified = cv.misclassifications
+    
+    attr(y, "description") = "classification results in a compact form"
+    # attr(misclassified, "description") = "misclassified samples [still not working properly]"
+    attr(predicted, "description") = "a vector of classes predicted by the classifier"
+    attr(expected, "description") = "ground truth, or a vector of expected classes"
+    attr(confusion_matrix, "description") = "confusion matrix for all cv folds"
 
 
-attr(classification.results, "confusion_matrix") = confusion_matrix
+    results = list()
+    results$y = y
+    # results$misclassified = misclassified
+    results$predicted = predicted
+    results$expected = expected
+    results$confusion_matrix = confusion_matrix
+    
 
+    # adding some information about the current function call
+    # to the final list of results
+    results$call = match.call()
+    results$name = call("perform.knn")
+    
+    class(results) = "stylo.results"
+    
+    return(results)
 
-
-
-return(classification.results)
 }
 
 
